@@ -77,7 +77,9 @@ mcmc = pyfstat.MCMCSearch(
     log10beta_min=log10beta_min,
 )
 mcmc.setup_initialisation(100, scatter_val=1e-10)
-mcmc.run()
-mcmc.plot_corner(add_prior=True)
-mcmc.plot_prior_posterior()
+mcmc.run(
+    walker_plot_args={"plot_det_stat": True, "injection_parameters": signal_parameters}
+)
 mcmc.print_summary()
+mcmc.plot_corner(add_prior=True, truths=signal_parameters)
+mcmc.plot_prior_posterior(injection_parameters=signal_parameters)
