@@ -78,10 +78,14 @@ mcmc = pyfstat.MCMCSemiCoherentSearch(
     log10beta_min=log10beta_min,
 )
 mcmc.transform_dictionary = dict(
-    F0=dict(subtractor=signal_parameters["F0"], symbol="$f-f^\mathrm{s}$"),
-    F1=dict(subtractor=signal_parameters["F1"], symbol="$\dot{f}-\dot{f}^\mathrm{s}$"),
+    F0=dict(subtractor=signal_parameters["F0"], symbol="$f-f^\\mathrm{s}$"),
+    F1=dict(
+        subtractor=signal_parameters["F1"], symbol="$\\dot{f}-\\dot{f}^\\mathrm{s}$"
+    ),
+)
+mcmc.run(
+    walker_plot_args={"plot_det_stat": True, "injection_parameters": signal_parameters}
 )
-mcmc.run()
-mcmc.plot_corner(add_prior=True)
-mcmc.plot_prior_posterior()
 mcmc.print_summary()
+mcmc.plot_corner(add_prior=True, truths=signal_parameters)
+mcmc.plot_prior_posterior(injection_parameters=signal_parameters)
