@@ -19,6 +19,7 @@ transient_duration = 0.5 * duration
 tref = tstart
 
 h0 = 1e-23
+cosi = 0
 sqrtSX = 1e-22
 detectors = "H1,L1"
 
@@ -36,11 +37,13 @@ transient = pyfstat.Writer(
     Alpha=Alpha,
     Delta=Delta,
     h0=h0,
+    cosi=cosi,
     detectors=detectors,
     sqrtSX=sqrtSX,
     transientStartTime=transient_tstart,
-    transientTau=transient_tstart,
+    transientTau=transient_duration,
     transientWindowType="rect",
     Tsft=Tsft,
+    Band=0.1,
 )
 transient.make_data()
