@@ -37,247 +37,14 @@ args, tqdm = helper_functions.set_up_command_line_arguments()
 detector_colors = {"h1": "C0", "l1": "C1"}
 
 
-def translate_keys_to_lal(dictionary):
-    """Convert input keys into lal input keys
-
-    Input keys are F0, F1, F2, ..., while LAL functions
-    prefer to use Freq, f1dot, f2dot, ....
-
-    Since lal keys are only used to call for lal routines,
-    it makes sense to have this function defined this way
-    so it can be called on the fly.
-
-    Parameters
-    ----------
-    dictionary: dict
-        Dictionary to translate. A copy will be made (an returned)
-        before translation takes place.
-
-    Returns
-    -------
-    translated_dict: dict
-        Copy of "dictionary" with new keys according to lal.
-    """
-
-    translation = {
-        "F0": "Freq",
-        "F1": "f1dot",
-        "F2": "f2dot",
-        "phi": "phi0",
-        "tref": "refTime",
-        "asini": "orbitasini",
-        "period": "orbitPeriod",
-        "tp": "orbitTp",
-        "argp": "orbitArgp",
-        "ecc": "orbitEcc",
-        "transient_tstart": "transient-t0Epoch",
-        "transient_duration": "transient-tau",
-    }
-
-    keys_to_translate = [key for key in dictionary.keys() if key in translation]
-
-    translated_dict = dictionary.copy()
-    for key in keys_to_translate:
-        translated_dict[translation[key]] = translated_dict.pop(key)
-    return translated_dict
-
-
-class Bunch(object):
-    """ Turns dictionary into object with attribute-style access
-
-    Parameters
-    ----------
-    dict
-        Input dictionary
-
-    Examples
-    --------
-    >>> data = Bunch(dict(x=1, y=[1, 2, 3], z=True))
-    >>> print(data.x)
-    1
-    >>> print(data.y)
-    [1, 2, 3]
-    >>> print(data.z)
-    True
-
-    """
-
-    def __init__(self, dictionary):
-        self.__dict__.update(dictionary)
-
-
-def read_par(
-    filename=None,
-    label=None,
-    outdir=None,
-    suffix="par",
-    return_type="dict",
-    comments=["%", "#"],
-    raise_error=False,
-):
-    """ Read in a .par or .loudest file, returns a dict or Bunch of the data
-
-    Parameters
-    ----------
-    filename : str
-        Filename (path) containing rows of `key=val` data to read in.
-    label, outdir, suffix : str, optional
-        If filename is None, form the file to read as `outdir/label.suffix`.
-    return_type : {'dict', 'bunch'}, optional
-        If `dict`, return a dictionary, if 'bunch' return a Bunch
-    comments : str or list of strings, optional
-        Characters denoting that a row is a comment.
-    raise_error : bool, optional
-        If True, raise an error for lines which are not comments, but cannot
-        be read.
-
-    Notes
-    -----
-    This can also be used to read in .loudest files, or any file which has
-    rows of `key=val` data (in which the val can be understood using eval(val)
-
-    Returns
-    -------
-    d: Bunch or dict
-        The par values as either a `Bunch` or dict type
-
-    """
-    if filename is None:
-        filename = os.path.join(outdir, "{}.{}".format(label, suffix))
-    if os.path.isfile(filename) is False:
-        raise ValueError("No file {} found".format(filename))
-    d = {}
-    with open(filename, "r") as f:
-        d = _get_dictionary_from_lines(f, comments, raise_error)
-    if return_type in ["bunch", "Bunch"]:
-        return Bunch(d)
-    elif return_type in ["dict", "dictionary"]:
-        return d
-    else:
-        raise ValueError("return_type {} not understood".format(return_type))
-
-
-def _get_dictionary_from_lines(lines, comments, raise_error):
-    """ Return dictionary of key=val pairs for each line in lines
-
-    Parameters
-    ----------
-    comments : str or list of strings
-        Characters denoting that a row is a comment.
-    raise_error : bool
-        If True, raise an error for lines which are not comments, but cannot
-        be read.
-
-    Returns
-    -------
-    d: Bunch or dict
-        The par values as either a `Bunch` or dict type
-
-    """
-    d = {}
-    for line in lines:
-        if line[0] not in comments and len(line.split("=")) == 2:
-            try:
-                key, val = line.rstrip("\n").split("=")
-                key = key.strip()
-                val = val.strip()
-                if (val[0] in ["'", '"']) and (val[-1] in ["'", '"']):
-                    d[key] = val.lstrip('"').lstrip("'").rstrip('"').rstrip("'")
-                else:
-                    try:
-                        d[key] = np.float64(eval(val.rstrip("; ")))
-                    except NameError:
-                        d[key] = val.rstrip("; ")
-            except SyntaxError:
-                if raise_error:
-                    raise IOError("Line {} not understood".format(line))
-                pass
-    return d
-
-
-def predict_fstat(
-    h0,
-    cosi,
-    psi,
-    Alpha,
-    Delta,
-    Freq,
-    sftfilepattern,
-    minStartTime,
-    maxStartTime,
-    IFOs=None,
-    assumeSqrtSX=None,
-    tempory_filename="fs.tmp",
-    earth_ephem=None,
-    sun_ephem=None,
-    transientWindowType="none",
-    transientStartTime=None,
-    transientTau=None,
-    **kwargs
-):
-    """ Wrapper to lalapps_PredictFstat
-
-    Parameters
-    ----------
-    h0, cosi, psi, Alpha, Delta, Freq : float
-        Signal properties, see `lalapps_PredictFstat --help` for more info.
-    sftfilepattern : str
-        Pattern matching the sftfiles to use.
-    minStartTime, maxStartTime : int
-    IFOs : str
-        See `lalapps_PredictFstat --help`
-    assumeSqrtSX : float or None
-        See `lalapps_PredictFstat --help`, if None this option is not used
-
-    Returns
-    -------
-    twoF_expected, twoF_sigma : float
-        The expectation and standard deviation of 2F
-
-    """
-
-    cl_pfs = []
-    cl_pfs.append("lalapps_PredictFstat")
-    cl_pfs.append("--h0={}".format(h0))
-    cl_pfs.append("--cosi={}".format(cosi))
-    cl_pfs.append("--psi={}".format(psi))
-    cl_pfs.append("--Alpha={}".format(Alpha))
-    cl_pfs.append("--Delta={}".format(Delta))
-    cl_pfs.append("--Freq={}".format(Freq))
-
-    cl_pfs.append("--DataFiles='{}'".format(sftfilepattern))
-    if assumeSqrtSX:
-        cl_pfs.append("--assumeSqrtSX={}".format(assumeSqrtSX))
-    # if IFOs:
-    #    cl_pfs.append("--IFOs={}".format(IFOs))
-
-    cl_pfs.append("--minStartTime={}".format(int(minStartTime)))
-    cl_pfs.append("--maxStartTime={}".format(int(maxStartTime)))
-    cl_pfs.append("--outputFstat={}".format(tempory_filename))
-
-    earth_ephem_default, sun_ephem_default = helper_functions.get_ephemeris_files()
-    if earth_ephem is None:
-        earth_ephem = earth_ephem_default
-    if sun_ephem is None:
-        sun_ephem = sun_ephem_default
-    cl_pfs.append("--ephemEarth='{}'".format(earth_ephem))
-    cl_pfs.append("--ephemSun='{}'".format(sun_ephem))
-
-    if transientWindowType != "none":
-        cl_pfs.append("--transientWindowType='{}'".format(transientWindowType))
-        cl_pfs.append("--transientStartTime='{}'".format(transientStartTime))
-        cl_pfs.append("--transientTau='{}'".format(transientTau))
-
-    cl_pfs = " ".join(cl_pfs)
-    helper_functions.run_commandline(cl_pfs)
-    d = read_par(filename=tempory_filename)
-    os.remove(tempory_filename)
-    return float(d["twoF_expected"]), float(d["twoF_sigma"])
-
-
-class BaseSearchClass(object):
+class BaseSearchClass:
     """ The base search class providing parent methods to other searches """
 
+    def __new__(cls, *args, **kwargs):
+        logging.info(f"Creating {cls.__name__} object...")
+        instance = super().__new__(cls)
+        return instance
+
     def _add_log_file(self, header=None):
         """ Log output to a file, requires class to have outdir and label """
         header = [] if header is None else header
@@ -294,109 +61,6 @@ class BaseSearchClass(object):
         )
         logging.getLogger().addHandler(fh)
 
-    def _shift_matrix(self, n, dT):
-        """ Generate the shift matrix
-
-        Parameters
-        ----------
-        n : int
-            The dimension of the shift-matrix to generate
-        dT : float
-            The time delta of the shift matrix
-
-        Returns
-        -------
-        m : ndarray, shape (n,)
-            The shift matrix.
-
-        """
-        m = np.zeros((n, n))
-        factorial = np.math.factorial
-        for i in range(n):
-            for j in range(n):
-                if i == j:
-                    m[i, j] = 1.0
-                elif i > j:
-                    m[i, j] = 0.0
-                else:
-                    if i == 0:
-                        m[i, j] = 2 * np.pi * float(dT) ** (j - i) / factorial(j - i)
-                    else:
-                        m[i, j] = float(dT) ** (j - i) / factorial(j - i)
-        return m
-
-    def _shift_coefficients(self, theta, dT):
-        """ Shift a set of coefficients by dT
-
-        Parameters
-        ----------
-        theta : array-like, shape (n,)
-            Vector of the expansion coefficients to transform starting from the
-            lowest degree e.g [phi, F0, F1,...].
-        dT : float
-            Difference between the two reference times as tref_new - tref_old.
-
-        Returns
-        -------
-        theta_new : ndarray, shape (n,)
-            Vector of the coefficients as evaluated as the new reference time.
-        """
-        n = len(theta)
-        m = self._shift_matrix(n, dT)
-        return np.dot(m, theta)
-
-    def _calculate_thetas(self, theta, delta_thetas, tbounds, theta0_idx=0):
-        """ Calculates the set of thetas given delta_thetas, the jumps
-
-        This is used when generating data containing glitches or timing noise.
-        Specifically, the source parameters of the signal are not constant in
-        time, but jump by `delta_theta` at `tbounds`.
-
-        Parameters
-        ----------
-        theta : array_like
-            The source parameters of size (n,).
-        delta_thetas : array_like
-            The jumps in the source parameters of size (m, n) where m is the
-            number of jumps.
-        tbounds : array_like
-            Time boundaries of the jumps of size (m+2,).
-        theta0_idx : int
-            Index of the segment for which the theta are defined.
-
-        Returns
-        -------
-        ndarray
-            The set of thetas, shape (m+1, n).
-
-        """
-        thetas = [theta]
-        for i, dt in enumerate(delta_thetas):
-            if i < theta0_idx:
-                pre_theta_at_ith_glitch = self._shift_coefficients(
-                    thetas[0], tbounds[i + 1] - self.tref
-                )
-                post_theta_at_ith_glitch = pre_theta_at_ith_glitch - dt
-                thetas.insert(
-                    0,
-                    self._shift_coefficients(
-                        post_theta_at_ith_glitch, self.tref - tbounds[i + 1]
-                    ),
-                )
-
-            elif i >= theta0_idx:
-                pre_theta_at_ith_glitch = self._shift_coefficients(
-                    thetas[i], tbounds[i + 1] - self.tref
-                )
-                post_theta_at_ith_glitch = pre_theta_at_ith_glitch + dt
-                thetas.append(
-                    self._shift_coefficients(
-                        post_theta_at_ith_glitch, self.tref - tbounds[i + 1]
-                    )
-                )
-        self.thetas_at_tref = thetas
-        return thetas
-
     def _get_list_of_matching_sfts(self):
         """ Returns a list of sfts matching the attribute sftfilepattern """
         sftfilepatternlist = np.atleast_1d(self.sftfilepattern.split(";"))
@@ -408,7 +72,7 @@ class BaseSearchClass(object):
             raise IOError("No sfts found matching {}".format(self.sftfilepattern))
 
     def set_ephemeris_files(self, earth_ephem=None, sun_ephem=None):
-        """ Set the ephemeris files to use for the Earth and Sun
+        """Set the ephemeris files to use for the Earth and Sun
 
         Parameters
         ----------
@@ -474,6 +138,62 @@ class BaseSearchClass(object):
         header += self.pprint_init_params_dict()
         return header
 
+    def read_par(
+        self, filename=None, label=None, outdir=None, suffix="par", raise_error=True
+    ):
+        params_dict = helper_functions.read_par(
+            filename=filename,
+            label=label or getattr(self, "label", None),
+            outdir=outdir or getattr(self, "outdir", None),
+            suffix=suffix,
+            raise_error=raise_error,
+        )
+        return params_dict
+
+    def translate_keys_to_lal(self, dictionary):
+        """Convert input keys into lal input keys
+
+        Input keys are F0, F1, F2, ..., while LAL functions
+        prefer to use Freq, f1dot, f2dot, ....
+
+        Since lal keys are only used to call for lal routines,
+        it makes sense to have this function defined this way
+        so it can be called on the fly.
+
+        Parameters
+        ----------
+        dictionary: dict
+            Dictionary to translate. A copy will be made (an returned)
+            before translation takes place.
+
+        Returns
+        -------
+        translated_dict: dict
+            Copy of "dictionary" with new keys according to lal.
+        """
+
+        translation = {
+            "F0": "Freq",
+            "F1": "f1dot",
+            "F2": "f2dot",
+            "phi": "phi0",
+            "tref": "refTime",
+            "asini": "orbitasini",
+            "period": "orbitPeriod",
+            "tp": "orbitTp",
+            "argp": "orbitArgp",
+            "ecc": "orbitEcc",
+            "transient_tstart": "transient-t0Epoch",
+            "transient_duration": "transient-tau",
+        }
+
+        keys_to_translate = [key for key in dictionary.keys() if key in translation]
+
+        translated_dict = dictionary.copy()
+        for key in keys_to_translate:
+            translated_dict[translation[key]] = translated_dict.pop(key)
+        return translated_dict
+
 
 class ComputeFstat(BaseSearchClass):
     """ Base class providing interface to `lalpulsar.ComputeFstat` """
@@ -508,7 +228,6 @@ class ComputeFstat(BaseSearchClass):
         computeAtoms=False,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -543,8 +262,9 @@ class ComputeFstat(BaseSearchClass):
             grid resolutions in transient start-time and duration,
             both default to Tsft
         detectors : str
-            Two character reference to the data to use, specify None for no
-            contraint. If multiple-separate by comma.
+            Two-character references to the detectors for which to use data.
+            Specify None for no constraint.
+            For multiple detectors, separate by comma.
         minCoverFreq, maxCoverFreq : float
             The min and max cover frequency passed to CreateFstatInput.
             For negative values, these will be used as offsets from the min/max
@@ -591,26 +311,15 @@ class ComputeFstat(BaseSearchClass):
             Sun ephemeris file path
             if None, will check standard sources as per
             helper_functions.get_ephemeris_files()
-        estimate_covering_band : bool
-            DEPRECATED: default behaviour is now equivalent to old
-            estimate_covering_band=True.
         """
 
-        if estimate_covering_band is not None:
-            raise ValueError(
-                "Option 'estimate_covering_band' is no longer supported!"
-                " Default behaviour is now equivalent to old"
-                " estimate_covering_band=True,"
-                " unless [minCoverFreq,maxCoverFreq] are given."
-            )
-
         self._set_init_params_dict(locals())
         self.set_ephemeris_files(earth_ephem, sun_ephem)
         self.init_computefstatistic()
         self.output_file_header = self.get_output_file_header()
 
     def _get_SFTCatalog(self):
-        """ Load the SFTCatalog
+        """Load the SFTCatalog
 
         If sftfilepattern is specified, load the data. If not, attempt to
         create data on the fly.
@@ -654,8 +363,8 @@ class ComputeFstat(BaseSearchClass):
         if self.detectors:
             if "," in self.detectors:
                 logging.warning(
-                    "Multiple detector selection not available,"
-                    " using all available data"
+                    "Multiple-detector constraints not available,"
+                    " using all available data."
                 )
             else:
                 constraints.detector = self.detectors
@@ -714,13 +423,12 @@ class ComputeFstat(BaseSearchClass):
             # maxStartTime must always be > last actual SFT timestamp
             self.maxStartTime = int(SFT_timestamps[-1]) + self.Tsft
 
-        detector_names = list(set([d.header.name for d in self.SFTCatalog.data]))
-        self.detector_names = detector_names
-        if len(detector_names) == 0:
+        self.detector_names = list(set([d.header.name for d in self.SFTCatalog.data]))
+        if len(self.detector_names) == 0:
             raise ValueError("No data loaded.")
         logging.info(
-            "Loaded {} data files from detectors {}".format(
-                len(SFT_timestamps), detector_names
+            "Loaded {} SFTs from detectors {}".format(
+                len(SFT_timestamps), self.detector_names
             )
         )
 
@@ -1057,7 +765,10 @@ class ComputeFstat(BaseSearchClass):
             else 0.0
         )
         searchRegion.skyRegionString = lalpulsar.SkySquare2String(
-            Alpha, Delta, AlphaBand, DeltaBand,
+            Alpha,
+            Delta,
+            AlphaBand,
+            DeltaBand,
         )
         searchRegion.refTime = self.tref
         # frequency and spindowns
@@ -1246,7 +957,7 @@ class ComputeFstat(BaseSearchClass):
         tend=None,
         npoints=1000,
     ):
-        """ Calculate the cumulative twoF along the obseration span
+        """Calculate the cumulative twoF along the obseration span
 
         Parameters
         ----------
@@ -1300,7 +1011,7 @@ class ComputeFstat(BaseSearchClass):
     def _calculate_predict_fstat_cumulative(
         self, N, label=None, outdir=None, IFO=None, pfs_input=None
     ):
-        """ Calculates the predicted 2F and standard deviation cumulatively
+        """Calculates the predicted 2F and standard deviation cumulatively
 
         Parameters
         ----------
@@ -1322,7 +1033,9 @@ class ComputeFstat(BaseSearchClass):
         if pfs_input is None:
             if os.path.isfile(os.path.join(outdir, label + ".loudest")) is False:
                 raise ValueError("Need a loudest file to add the predicted Fstat")
-            loudest = read_par(label=label, outdir=outdir, suffix="loudest")
+            loudest = self.read_par(
+                label=label, outdir=outdir, suffix="loudest", raise_error=False
+            )
             pfs_input = {
                 key: loudest[key]
                 for key in ["h0", "cosi", "psi", "Alpha", "Delta", "Freq"]
@@ -1330,12 +1043,12 @@ class ComputeFstat(BaseSearchClass):
         times = np.linspace(self.minStartTime, self.maxStartTime, N + 1)[1:]
         times = np.insert(times, 0, self.minStartTime + 86400 / 2.0)
         out = [
-            predict_fstat(
+            helper_functions.predict_fstat(
                 minStartTime=self.minStartTime,
                 maxStartTime=t,
                 sftfilepattern=self.sftfilepattern,
                 IFO=IFO,
-                **pfs_input
+                **pfs_input,
             )
             for t in times
         ]
@@ -1354,9 +1067,9 @@ class ComputeFstat(BaseSearchClass):
         savefig=True,
         title=None,
         plt_label=None,
-        **kwargs
+        **kwargs,
     ):
-        """ Plot the twoF value cumulatively
+        """Plot the twoF value cumulatively
 
         Parameters
         ----------
@@ -1492,7 +1205,7 @@ class ComputeFstat(BaseSearchClass):
                 self.sun_ephem,
             )
         )
-        loudest = read_par(LoudestFile, return_type="dict")
+        loudest = self.read_par(filename=LoudestFile, raise_error=False)
         os.remove(LoudestFile)
         return loudest
 
@@ -1547,7 +1260,6 @@ class SemiCoherentSearch(ComputeFstat):
         RngMedWindow=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -1572,14 +1284,6 @@ class SemiCoherentSearch(ComputeFstat):
         For all other parameters, see pyfstat.ComputeFStat.
         """
 
-        if estimate_covering_band is not None:
-            raise ValueError(
-                "Option 'estimate_covering_band' is no longer supported!"
-                " Default behaviour is now equivalent to old"
-                " estimate_covering_band=True,"
-                " unless [minCoverFreq,maxCoverFreq] are given."
-            )
-
         self.fs_file_name = os.path.join(self.outdir, self.label + "_FS.dat")
         self.set_ephemeris_files(earth_ephem, sun_ephem)
         self.transientWindowType = None  # will use semicoherentWindowRange instead
@@ -1592,7 +1296,7 @@ class SemiCoherentSearch(ComputeFstat):
     def _init_semicoherent_window_range(self):
         """
         Use this window to compute the semicoherent Fstat using TransientFstatMaps.
-        This way we are able to decouple the semicoherent computation from the 
+        This way we are able to decouple the semicoherent computation from the
         actual usage of a transient window.
         """
         self.semicoherentWindowRange = lalpulsar.transientWindowRange_t()
@@ -1739,8 +1443,115 @@ class SemiCoherentSearch(ComputeFstat):
         return twoF
 
 
-class SemiCoherentGlitchSearch(ComputeFstat):
-    """ A semi-coherent glitch search
+class SearchForSignalWithJumps(BaseSearchClass):
+    """ A class which just adds some useful methods for glitches or timing noise """
+
+    def _shift_matrix(self, n, dT):
+        """Generate the shift matrix
+
+        Parameters
+        ----------
+        n : int
+            The dimension of the shift-matrix to generate
+        dT : float
+            The time delta of the shift matrix
+
+        Returns
+        -------
+        m : ndarray, shape (n,)
+            The shift matrix.
+
+        """
+        m = np.zeros((n, n))
+        factorial = np.math.factorial
+        for i in range(n):
+            for j in range(n):
+                if i == j:
+                    m[i, j] = 1.0
+                elif i > j:
+                    m[i, j] = 0.0
+                else:
+                    if i == 0:
+                        m[i, j] = 2 * np.pi * float(dT) ** (j - i) / factorial(j - i)
+                    else:
+                        m[i, j] = float(dT) ** (j - i) / factorial(j - i)
+        return m
+
+    def _shift_coefficients(self, theta, dT):
+        """Shift a set of coefficients by dT
+
+        Parameters
+        ----------
+        theta : array-like, shape (n,)
+            Vector of the expansion coefficients to transform starting from the
+            lowest degree e.g [phi, F0, F1,...].
+        dT : float
+            Difference between the two reference times as tref_new - tref_old.
+
+        Returns
+        -------
+        theta_new : ndarray, shape (n,)
+            Vector of the coefficients as evaluated as the new reference time.
+        """
+        n = len(theta)
+        m = self._shift_matrix(n, dT)
+        return np.dot(m, theta)
+
+    def _calculate_thetas(self, theta, delta_thetas, tbounds, theta0_idx=0):
+        """Calculates the set of thetas given delta_thetas, the jumps
+
+        This is used when generating data containing glitches or timing noise.
+        Specifically, the source parameters of the signal are not constant in
+        time, but jump by `delta_theta` at `tbounds`.
+
+        Parameters
+        ----------
+        theta : array_like
+            The source parameters of size (n,).
+        delta_thetas : array_like
+            The jumps in the source parameters of size (m, n) where m is the
+            number of jumps.
+        tbounds : array_like
+            Time boundaries of the jumps of size (m+2,).
+        theta0_idx : int
+            Index of the segment for which the theta are defined.
+
+        Returns
+        -------
+        ndarray
+            The set of thetas, shape (m+1, n).
+
+        """
+        thetas = [theta]
+        for i, dt in enumerate(delta_thetas):
+            if i < theta0_idx:
+                pre_theta_at_ith_glitch = self._shift_coefficients(
+                    thetas[0], tbounds[i + 1] - self.tref
+                )
+                post_theta_at_ith_glitch = pre_theta_at_ith_glitch - dt
+                thetas.insert(
+                    0,
+                    self._shift_coefficients(
+                        post_theta_at_ith_glitch, self.tref - tbounds[i + 1]
+                    ),
+                )
+
+            elif i >= theta0_idx:
+                pre_theta_at_ith_glitch = self._shift_coefficients(
+                    thetas[i], tbounds[i + 1] - self.tref
+                )
+                post_theta_at_ith_glitch = pre_theta_at_ith_glitch + dt
+                thetas.append(
+                    self._shift_coefficients(
+                        post_theta_at_ith_glitch, self.tref - tbounds[i + 1]
+                    )
+                )
+        self.thetas_at_tref = thetas
+        return thetas
+
+
+class SemiCoherentGlitchSearch(SearchForSignalWithJumps, ComputeFstat):
+    """A semi-coherent glitch search
 
     This implements a basic `semi-coherent glitch F-stat in which the data
     is divided into segments either side of the proposed glitches and the
@@ -1771,7 +1582,6 @@ class SemiCoherentGlitchSearch(ComputeFstat):
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -1794,14 +1604,6 @@ class SemiCoherentGlitchSearch(ComputeFstat):
         For all other parameters, see pyfstat.ComputeFStat.
         """
 
-        if estimate_covering_band is not None:
-            raise ValueError(
-                "Option 'estimate_covering_band' is no longer supported!"
-                " Default behaviour is now equivalent to old"
-                " estimate_covering_band=True,"
-                " unless [minCoverFreq,maxCoverFreq] are given."
-            )
-
         self.fs_file_name = os.path.join(self.outdir, self.label + "_FS.dat")
         self.set_ephemeris_files(earth_ephem, sun_ephem)
         self.transientWindowType = "rect"
@@ -1853,7 +1655,7 @@ class SemiCoherentGlitchSearch(ComputeFstat):
     def compute_glitch_fstat_single(
         self, F0, F1, F2, Alpha, Delta, delta_F0, delta_F1, tglitch
     ):
-        """ Returns the semi-coherent glitch summed twoF for nglitch=1
+        """Returns the semi-coherent glitch summed twoF for nglitch=1
 
         Note: OBSOLETE, used only for testing
         """
