@@ -20,7 +20,6 @@ from pyfstat.core import (
     SemiCoherentSearch,
     tqdm,
     args,
-    read_par,
 )
 import lalpulsar
 import lal
@@ -72,7 +71,6 @@ class GridSearch(BaseSearchClass):
         assumeSqrtSX=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -141,7 +139,6 @@ class GridSearch(BaseSearchClass):
                 assumeSqrtSX=self.assumeSqrtSX,
                 earth_ephem=self.earth_ephem,
                 sun_ephem=self.sun_ephem,
-                estimate_covering_band=self.estimate_covering_band,
             )
             self.search.get_det_stat = self.search.get_fullycoherent_twoF
         else:
@@ -159,7 +156,6 @@ class GridSearch(BaseSearchClass):
                 search_ranges=search_ranges,
                 detectors=self.detectors,
                 injectSources=self.injectSources,
-                estimate_covering_band=self.estimate_covering_band,
             )
 
             def cut_out_tstart_tend(*vals):
@@ -214,11 +210,11 @@ class GridSearch(BaseSearchClass):
                 return False
 
         logging.info("Checking header of '{:s}'".format(self.out_file))
-        old_params_dict_str_list = helper_functions.read_parameters_dict_lines_from_file_header(
-            self.out_file
+        old_params_dict_str_list = (
+            helper_functions.read_parameters_dict_lines_from_file_header(self.out_file)
         )
         new_params_dict_str_list = [
-            l.strip(" ") for l in self.pprint_init_params_dict()[1:-1]
+            line.strip(" ") for line in self.pprint_init_params_dict()[1:-1]
         ]
         unmatched = np.setxor1d(old_params_dict_str_list, new_params_dict_str_list)
         if len(unmatched) > 0:
@@ -239,7 +235,12 @@ class GridSearch(BaseSearchClass):
         new_data = np.nan_to_num(self.input_data.astype(np.float64))
         rtol, atol = self._get_tolerance_from_savetxt_fmt()
         column_matches = [
-            np.allclose(old_data[:, n], new_data[:, n], rtol=rtol[n], atol=atol[n],)
+            np.allclose(
+                old_data[:, n],
+                new_data[:, n],
+                rtol=rtol[n],
+                atol=atol[n],
+            )
             for n in range(len(self.coord_arrays))
         ]
         if np.all(column_matches):
@@ -440,7 +441,7 @@ class GridSearch(BaseSearchClass):
         ylabel=None,
         zlabel=None,
     ):
-        """ Plots a 2D grid of 2F values
+        """Plots a 2D grid of 2F values
 
         Parameters
         ----------
@@ -532,7 +533,7 @@ class GridSearch(BaseSearchClass):
             return ax
 
     def get_max_twoF(self):
-        """ Get the maximum twoF over the grid
+        """Get the maximum twoF over the grid
 
         Returns
         -------
@@ -608,7 +609,6 @@ class TransientGridSearch(GridSearch):
         cudaDeviceName=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -701,7 +701,6 @@ class TransientGridSearch(GridSearch):
             computeAtoms=self.outputAtoms,
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
-            estimate_covering_band=self.estimate_covering_band,
         )
         self.search.get_det_stat = self.search.get_fullycoherent_twoF
 
@@ -840,7 +839,6 @@ class SliceGridSearch(GridSearch):
         Lambda0=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -910,7 +908,6 @@ class SliceGridSearch(GridSearch):
             maxStartTime=self.maxStartTime,
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
-            estimate_covering_band=self.estimate_covering_band,
         )
 
         for i, ikey in enumerate(self.search_keys):
@@ -981,6 +978,7 @@ class SliceGridSearch(GridSearch):
 
         if save:
             fig.savefig(os.path.join(self.outdir, self.label + "_slice_projection.png"))
+            plt.close(fig)
         else:
             return fig, axes
 
@@ -1008,7 +1006,6 @@ class GridUniformPriorSearch:
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         dF0 = (theta_prior["F0"]["upper"] - theta_prior["F0"]["lower"]) / NF0
         dF1 = (theta_prior["F1"]["upper"] - theta_prior["F1"]["lower"]) / NF1
@@ -1035,7 +1032,6 @@ class GridUniformPriorSearch:
             RngMedWindow=RngMedWindow,
             earth_ephem=earth_ephem,
             sun_ephem=sun_ephem,
-            estimate_covering_band=self.estimate_covering_band,
         )
 
     def run(self):
@@ -1070,7 +1066,6 @@ class GridGlitchSearch(GridSearch):
         detectors=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Run a single-glitch grid search
@@ -1128,7 +1123,6 @@ class GridGlitchSearch(GridSearch):
             BSGL=self.BSGL,
             earth_ephem=earth_ephem,
             sun_ephem=sun_ephem,
-            estimate_covering_band=self.estimate_covering_band,
         )
         self.search.get_det_stat = self.search.get_semicoherent_nglitch_twoF
 
@@ -1175,7 +1169,6 @@ class SlidingWindow(GridSearch):
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -1223,7 +1216,6 @@ class SlidingWindow(GridSearch):
             injectSources=self.injectSources,
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
-            estimate_covering_band=self.estimate_covering_band,
         )
 
     def check_old_data_is_okay_to_use(self, out_file):
@@ -1317,7 +1309,6 @@ class FrequencySlidingWindow(GridSearch):
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -1376,7 +1367,6 @@ class FrequencySlidingWindow(GridSearch):
             injectSources=self.injectSources,
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
-            estimate_covering_band=self.estimate_covering_band,
         )
         self.search.get_det_stat = self.search.get_fullycoherent_twoF
 
@@ -1447,6 +1437,7 @@ class FrequencySlidingWindow(GridSearch):
         if savefig:
             plt.tight_layout()
             plt.savefig(os.path.join(self.outdir, self.label + "_sliding_window.png"))
+            plt.close()
         else:
             return ax
 
@@ -1624,7 +1615,12 @@ class EarthTest(GridSearch):
         return F_at_zero - marginalised_F, (F_at_zero - max_F) / F_at_zero
 
     def plot_corner(
-        self, prior_widths=None, fig=None, axes=None, projection="log_mean"
+        self,
+        prior_widths=None,
+        fig=None,  # FIXME: looks like this is currently ignored
+        axes=None,  # FIXME: looks like this is currently ignored
+        save_fig=True,
+        projection="log_mean",
     ):
         Bsa, FmaxMismatch = self.marginalised_bayes_factor(prior_widths)
 
@@ -1664,7 +1660,13 @@ class EarthTest(GridSearch):
             y=0.99,
             size=14,
         )
-        fig.savefig(os.path.join(self.outdir, self.label + "_projection_matrix.png"))
+        if save_fig:
+            fig.savefig(
+                os.path.join(self.outdir, self.label + "_projection_matrix.png")
+            )
+            plt.close(fig)
+        else:
+            return fig, axes
 
     def plot(self, key, prior_widths=None):
         Bsa, FmaxMismatch = self.marginalised_bayes_factor(prior_widths)
@@ -1690,6 +1692,7 @@ class EarthTest(GridSearch):
         )
         fig.tight_layout()
         fig.savefig(os.path.join(self.outdir, self.label + "_1D.png"))
+        plt.close(fig)
 
 
 class DMoff_NO_SPIN(GridSearch):
@@ -1736,7 +1739,7 @@ class DMoff_NO_SPIN(GridSearch):
         if type(par) == dict:
             self.par = par
         elif type(par) == str and os.path.isfile(par):
-            self.par = read_par(filename=par)
+            self.par = self.read_par(filename=par)
         else:
             raise ValueError("The .par file does not exist")
 
@@ -1755,7 +1758,7 @@ class DMoff_NO_SPIN(GridSearch):
         logging.info("Setting up DMoff_NO_SPIN search with m0 = {}".format(self.m0))
 
     def get_results(self):
-        """ Compute the three summed detection statistics
+        """Compute the three summed detection statistics
 
         Returns
         -------
