@@ -141,7 +141,7 @@ def get_ephemeris_files():
         try:
             earth_ephem = d["earth_ephem"]
             sun_ephem = d["sun_ephem"]
-        except:
+        except KeyError:
             logging.warning(
                 "No [earth/sun]_ephem found in " + config_file + ". " + please
             )
@@ -307,7 +307,7 @@ def run_commandline(cl, log_level=20, raise_error=True, return_output=True):
                 universal_newlines=True,  # properly display linebreaks in error/output printing
             )
         else:
-            process = subprocess.check_call(cl, shell=True)
+            subprocess.check_call(cl, shell=True)
     except subprocess.CalledProcessError as e:
         logging.log(40, "Execution failed: {}".format(e))
         if e.output:
@@ -328,7 +328,7 @@ def convert_array_to_gsl_matrix(array):
 
 
 def get_sft_array(sftfilepattern, data_duration=None, F0=None, dF0=None):
-    """ Return the raw data (absolute value) from a set of SFTs
+    """Return the raw data (absolute value) from a set of SFTs
 
     FIXME: currently only returns data for first detector
     """
@@ -382,7 +382,7 @@ def get_covering_band(
     minOrbitPeriod=0.0,
     maxOrbitEcc=0.0,
 ):
-    """ Get the covering band using XLALCWSignalCoveringBand
+    """Get the covering band using XLALCWSignalCoveringBand
 
     Parameters
     ----------
@@ -499,7 +499,7 @@ def read_txt_file_with_header(f, comments="#"):
 
 
 def get_lalapps_commandline_from_SFTDescriptor(descriptor):
-    """ get a lalapps commandline from SFT descriptor "comment" entry
+    """get a lalapps commandline from SFT descriptor "comment" entry
 
     Parameters
     ----------
@@ -523,7 +523,7 @@ def get_lalapps_commandline_from_SFTDescriptor(descriptor):
 def read_parameters_dict_lines_from_file_header(
     outfile, comments="#", strip_spaces=True
 ):
-    """ load a list of pretty-printed parameters dictionary lines from a commented file header
+    """load a list of pretty-printed parameters dictionary lines from a commented file header
 
     Returns a list of lines from a commented file header
     that match the pretty-printed parameters dictionary format
@@ -574,7 +574,7 @@ def read_parameters_dict_lines_from_file_header(
 
 
 def get_parameters_dict_from_file_header(outfile, comments="#", eval_values=False):
-    """ load a parameters dict from a commented file header
+    """load a parameters dict from a commented file header
 
     Returns a parameters dictionary,
     as generated by BaseSearchClass.get_output_file_header(),
@@ -628,3 +628,236 @@ def get_parameters_dict_from_file_header(outfile, comments="#", eval_values=Fals
             val = eval(val)  # DANGER
         params_dict[key] = val
     return params_dict
+
+
+def read_par(
+    filename=None,
+    label=None,
+    outdir=None,
+    suffix="par",
+    comments=["%", "#"],
+    raise_error=False,
+):
+    """Read in a .par or .loudest file, returns a dict of the data
+
+    Parameters
+    ----------
+    filename : str
+        Filename (path) containing rows of `key=val` data to read in.
+    label, outdir, suffix : str, optional
+        If filename is None, form the file to read as `outdir/label.suffix`.
+    comments : str or list of strings, optional
+        Characters denoting that a row is a comment.
+    raise_error : bool, optional
+        If True, raise an error for lines which are not comments, but cannot
+        be read.
+
+    Notes
+    -----
+    This can also be used to read in .loudest files, or any file which has
+    rows of `key=val` data (in which the val can be understood using eval(val)
+
+    Returns
+    -------
+    d: dict
+        The par values as a dict type
+
+    """
+    if filename is None:
+        filename = os.path.join(outdir, "{}.{}".format(label, suffix))
+    if os.path.isfile(filename) is False:
+        raise ValueError("No file {} found".format(filename))
+    d = {}
+    with open(filename, "r") as f:
+        d = get_dictionary_from_lines(f, comments, raise_error)
+    return d
+
+
+def get_dictionary_from_lines(lines, comments, raise_error):
+    """Return dictionary of key=val pairs for each line in lines
+
+    Parameters
+    ----------
+    comments : str or list of strings
+        Characters denoting that a row is a comment.
+    raise_error : bool
+        If True, raise an error for lines which are not comments, but cannot
+        be read.
+        Note that CFSv2 "loudest" files contain complex numbers which fill raise
+        an error unless this is set to False.
+
+    Returns
+    -------
+    d: dict
+        The par values as a dict type
+
+    """
+    d = {}
+    for line in lines:
+        if line[0] not in comments and len(line.split("=")) == 2:
+            try:
+                key, val = line.rstrip("\n").split("=")
+                key = key.strip()
+                val = val.strip()
+                if (val[0] in ["'", '"']) and (val[-1] in ["'", '"']):
+                    d[key] = val.lstrip('"').lstrip("'").rstrip('"').rstrip("'")
+                else:
+                    try:
+                        d[key] = np.float64(eval(val.rstrip("; ")))
+                    except NameError:
+                        d[key] = val.rstrip("; ")
+                    # FIXME: learn how to deal with complex numbers
+            except SyntaxError:
+                if raise_error:
+                    raise IOError("Line {} not understood".format(line))
+                pass
+    return d
+
+
+def predict_fstat(
+    h0=None,
+    cosi=None,
+    psi=None,
+    Alpha=None,
+    Delta=None,
+    Freq=None,
+    sftfilepattern=None,
+    timestampsFiles=None,
+    minStartTime=None,
+    duration=None,
+    IFOs=None,
+    assumeSqrtSX=None,
+    tempory_filename="fs.tmp",
+    earth_ephem=None,
+    sun_ephem=None,
+    transientWindowType="none",
+    transientStartTime=None,
+    transientTau=None,
+    **kwargs
+):
+    """Wrapper to lalapps_PredictFstat
+
+    Parameters
+    ----------
+    h0, cosi, psi, Alpha, Delta : float
+        Signal properties, see `lalapps_PredictFstat --help` for more info.
+    Freq: float or None
+        Only needed for noise floor estimation when given sftfilepattern
+        but assumeSqrtSX is None.
+    sftfilepattern : str or None
+        Pattern matching the sftfiles to use.
+    timestampsFiles : str or None
+        Comma-separated list of per-detector files containing timestamps to use.
+        Only used if no sftfilepattern given.
+    minStartTime, duration : int or None
+        If sftfilepattern given: used as optional constraints.
+        If timestampsFiles given: ignored.
+        If neither given: used as the interval for prediction.
+    IFOs : str or None
+        Comma-separated list of detectors.
+        Ignored if sftfilepattern is given,
+        required if it is not.
+    assumeSqrtSX : float or str or None
+        Assume stationary per-detector noise-floor instead of estimating from SFTs.
+        For multiple detectors: comma-separated list
+        Required if sftfilepattern is not given,
+        optional if it is.
+    tempory_filename : str
+        Temporary file used for lalapps_PredictFstat output, will be deleted.
+    earth_ephem, sun_ephem : str or None
+        Ephemerides files, defaults will be used if None.
+    transientWindowType: str
+        Optional parameter for transient signals,
+        see `lalapps_PredictFstat --help`.
+        Default of "none" means a classical Continuous Wave signal.
+    transientStartTime, transientTau: int or None
+        Optional parameters for transient signals,
+        see `lalapps_PredictFstat --help`.
+
+    Returns
+    -------
+    twoF_expected, twoF_sigma : float
+        The expectation and standard deviation of 2F.
+
+    """
+
+    cl_pfs = []
+    cl_pfs.append("lalapps_PredictFstat")
+
+    if h0 is not None:
+        cl_pfs.append("--h0={}".format(h0))
+    if cosi is not None:
+        cl_pfs.append("--cosi={}".format(cosi))
+    # NOTE: as of lalsuite 6.76, [psi,Alpha,Delta] are required even for
+    # noise-only calls, hence we default them to 0 if h0 is None or ==0,
+    # but fail if they're not set with h0>0.
+    # This can likely be simplified after a future lalsuite release.
+    pars = {"psi": psi, "Alpha": Alpha, "Delta": Delta}
+    for par in pars.keys():
+        if pars[par] is None:
+            if h0:
+                raise ValueError(
+                    "For h0>0, {:s} needs to be set explicitly.".format(par)
+                )
+            else:
+                cl_pfs.append("--{:s}=0".format(par))
+        else:
+            cl_pfs.append("--{:s}={}".format(par, pars[par]))
+
+    if sftfilepattern is None:
+        if IFOs is None or assumeSqrtSX is None:
+            raise ValueError("Without sftfilepattern, need IFOs and assumeSqrtSX!")
+        cl_pfs.append("--IFOs={}".format(IFOs))
+        if timestampsFiles is None:
+            if minStartTime is None or duration is None:
+                raise ValueError(
+                    "Without sftfilepattern, need timestampsFiles or [minStartTime,duration]!"
+                )
+            else:
+                cl_pfs.append("--minStartTime={}".format(minStartTime))
+                cl_pfs.append("--duration={}".format(duration))
+        else:
+            if len(timestampsFiles.split(",")) != len(IFOs.split(",")):
+                # checking this manually here because PFS would segfault
+                raise ValueError("timestampsFiles and IFOs must have same length!")
+            cl_pfs.append("--timestampsFiles={}".format(timestampsFiles))
+    else:
+        cl_pfs.append("--DataFiles='{}'".format(sftfilepattern))
+        if minStartTime is not None:
+            cl_pfs.append("--minStartTime={}".format(minStartTime))
+            if duration is not None:
+                cl_pfs.append("--maxStartTime={}".format(minStartTime + duration))
+        if assumeSqrtSX is None:
+            if Freq is None:
+                raise ValueError(
+                    "With sftfilepattern but without assumeSqrtSX,"
+                    " we need Freq to estimate noise floor."
+                )
+            cl_pfs.append("--Freq={}".format(Freq))
+    if assumeSqrtSX is not None:
+        if assumeSqrtSX <= 0:
+            raise ValueError("assumeSqrtSX must be >0!")
+        cl_pfs.append("--assumeSqrtSX={}".format(assumeSqrtSX))
+
+    cl_pfs.append("--outputFstat={}".format(tempory_filename))
+
+    earth_ephem_default, sun_ephem_default = get_ephemeris_files()
+    if earth_ephem is None:
+        earth_ephem = earth_ephem_default
+    if sun_ephem is None:
+        sun_ephem = sun_ephem_default
+    cl_pfs.append("--ephemEarth='{}'".format(earth_ephem))
+    cl_pfs.append("--ephemSun='{}'".format(sun_ephem))
+
+    if transientWindowType != "none":
+        cl_pfs.append("--transientWindowType='{}'".format(transientWindowType))
+        cl_pfs.append("--transientStartTime='{}'".format(transientStartTime))
+        cl_pfs.append("--transientTau='{}'".format(transientTau))
+
+    cl_pfs = " ".join(cl_pfs)
+    run_commandline(cl_pfs)
+    d = read_par(filename=tempory_filename)
+    twoF_expected = float(d["twoF_expected"])
+    twoF_sigma = float(d["twoF_sigma"])
+    os.remove(tempory_filename)
+    return twoF_expected, twoF_sigma
