@@ -6,6 +6,7 @@ import pyfstat
 import lalpulsar
 import logging
 import time
+from scipy.stats import chi2
 
 
 class BaseForTestsWithOutdir(unittest.TestCase):
@@ -54,6 +55,14 @@ default_Writer_params = {
     **default_signal_params,
 }
 
+default_binary_params = {
+    "period": 45 * 24 * 3600.0,
+    "asini": 10.0,
+    "tp": default_Writer_params["tstart"] + 0.25 * default_Writer_params["duration"],
+    "ecc": 0.5,
+    "argp": 0.3,
+}
+
 
 class BaseForTestsWithData(BaseForTestsWithOutdir):
     outdir = "TestData"
@@ -107,17 +116,6 @@ class TestWriter(BaseForTestsWithData):
     label = "TestWriter"
     writer_class_to_test = pyfstat.Writer
 
-    # def setup_method(self, method):
-    ## only setting up here, not actually running anything
-    # self.Writer = self.writer_class_to_test(
-    # label=self.label,
-    # outdir=self.outdir,
-    # tstart=self.tstart,
-    # duration=self.duration,
-    # detectors=self.detectors,
-    # **default_signal_params,
-    # )
-
     def test_make_cff(self):
         self.Writer.make_cff(verbose=True)
         self.assertTrue(
@@ -358,6 +356,54 @@ class TestBinaryModulatedWriter(TestWriter):
     label = "TestBinaryModulatedWriter"
     writer_class_to_test = pyfstat.BinaryModulatedWriter
 
+    def test_tp_parsing(self):
+        this_writer = self.writer_class_to_test(
+            outdir=self.outdir,
+            **default_Writer_params,
+            **default_binary_params,
+        )
+        this_writer.make_data()
+
+        theta_prior = {
+            key: value
+            for key, value in default_signal_params.items()
+            if key not in ["h0", "cosi"]
+        }
+        theta_prior.update({key: value for key, value in default_binary_params.items()})
+        theta_prior["tp"] = {
+            "type": "unif",
+            "lower": default_binary_params["tp"]
+            - 0.5 * default_binary_params["period"],
+            "upper": default_binary_params["tp"]
+            + 0.5 * default_binary_params["period"],
+        }
+        theta_prior.pop
+
+        mcmc_kwargs = {
+            "nsteps": [50],
+            "nwalkers": 150,
+            "ntemps": 3,
+        }
+        print(theta_prior)
+        mcmc = pyfstat.MCMCSearch(
+            binary=True,
+            label="tp_parsing",
+            outdir=self.outdir,
+            sftfilepattern=this_writer.sftfilepath,
+            theta_prior=theta_prior,
+            tref=this_writer.tstart,
+            minStartTime=this_writer.tstart,
+            maxStartTime=this_writer.tend(),
+            **mcmc_kwargs,
+        )
+        mcmc.run(plot_walkers=False)
+        max_twoF_sample, _ = mcmc.get_max_twoF()
+
+        relative_difference = np.abs(
+            1.0 - max_twoF_sample["tp"] / default_binary_params["tp"]
+        )
+        self.assertTrue(relative_difference < 1e-5)
+
 
 class TestGlitchWriter(TestWriter):
     label = "TestGlitchWriter"
@@ -429,76 +475,87 @@ class TestGlitchWriter(TestWriter):
         self.assertTrue(max_freq_glitch[-1] > max_freq_noglitch[-1])
 
 
-class TestBunch(unittest.TestCase):
-    def test_bunch(self):
-        b = pyfstat.core.Bunch(dict(x=10))
-        self.assertTrue(b.x == 10)
-
-
-class TestPar(BaseForTestsWithOutdir):
-    label = "TestPar"
+class TestReadParFile(BaseForTestsWithOutdir):
+    label = "TestReadParFile"
 
     def test(self):
         parfile = os.path.join(self.outdir, self.label + ".par")
         os.system('echo "x=100\ny=10" > ' + parfile)
 
-        par = pyfstat.core.read_par(parfile, return_type="Bunch")
-        self.assertTrue(par.x == 100)
-        self.assertTrue(par.y == 10)
+        par = pyfstat.helper_functions.read_par(filename=parfile)
+        self.assertTrue(par["x"] == 100)
+        self.assertTrue(par["y"] == 10)
 
-        par = pyfstat.core.read_par(
-            outdir=self.outdir, label=self.label, return_type="dict"
-        )
+        par = pyfstat.helper_functions.read_par(outdir=self.outdir, label=self.label)
         self.assertTrue(par["x"] == 100)
         self.assertTrue(par["y"] == 10)
 
 
-class TestBaseSearchClass(BaseForTestsWithData):
-    def test_shift_matrix(self):
-        BSC = pyfstat.BaseSearchClass()
-        dT = 10
-        a = BSC._shift_matrix(4, dT)
-        b = np.array(
-            [
-                [
-                    1,
-                    2 * np.pi * dT,
-                    2 * np.pi * dT ** 2 / 2.0,
-                    2 * np.pi * dT ** 3 / 6.0,
-                ],
-                [0, 1, dT, dT ** 2 / 2.0],
-                [0, 0, 1, dT],
-                [0, 0, 0, 1],
-            ]
+class TestPredictFstat(BaseForTestsWithOutdir):
+    label = "TestPredictFstat"
+    # here we only test the modes WITHOUT sftfilepattern,
+    # which itself is tested through the Writer and Search classes
+
+    def test_PFS_noise(self):
+        twoF_expected, twoF_sigma = pyfstat.helper_functions.predict_fstat(
+            minStartTime=default_Writer_params["tstart"],
+            duration=default_Writer_params["duration"],
+            IFOs=default_Writer_params["detectors"],
+            assumeSqrtSX=1,
         )
-        self.assertTrue(np.array_equal(a, b))
-
-    def test_shift_coefficients(self):
-        BSC = pyfstat.BaseSearchClass()
-        thetaA = np.array([10.0, 1e2, 10.0, 1e2])
-        dT = 100
-
-        # Calculate the 'long' way
-        thetaB = np.zeros(len(thetaA))
-        thetaB[3] = thetaA[3]
-        thetaB[2] = thetaA[2] + thetaA[3] * dT
-        thetaB[1] = thetaA[1] + thetaA[2] * dT + 0.5 * thetaA[3] * dT ** 2
-        thetaB[0] = thetaA[0] + 2 * np.pi * (
-            thetaA[1] * dT + 0.5 * thetaA[2] * dT ** 2 + thetaA[3] * dT ** 3 / 6.0
+        print(
+            "predict_fstat() returned: E[2F]={}+-{}".format(twoF_expected, twoF_sigma)
         )
+        self.assertTrue(twoF_expected == 4)
+        self.assertAlmostEqual(twoF_sigma, chi2.std(df=4), places=5)
 
-        self.assertTrue(np.array_equal(thetaB, BSC._shift_coefficients(thetaA, dT)))
-
-    def test_shift_coefficients_loop(self):
-        BSC = pyfstat.BaseSearchClass()
-        thetaA = np.array([10.0, 1e2, 10.0, 1e2])
-        dT = 1e1
-        thetaB = BSC._shift_coefficients(thetaA, dT)
-        self.assertTrue(
-            np.allclose(
-                thetaA, BSC._shift_coefficients(thetaB, -dT), rtol=1e-9, atol=1e-9
-            )
+    def test_PFS_noise_TSfiles(self):
+        IFOs = ["H1", "L1"]
+        TSfiles = [
+            os.path.join(self.outdir, "{:s}_{:s}.ts".format(self.label, IFO))
+            for IFO in IFOs
+        ]
+        for f in TSfiles:
+            with open(f, "w") as fp:
+                fp.write(
+                    "{:d} 0\n{:d} 0\n".format(
+                        default_Writer_params["tstart"],
+                        default_Writer_params["tstart"] + default_Writer_params["Tsft"],
+                    )
+                )
+        twoF_expected, twoF_sigma = pyfstat.helper_functions.predict_fstat(
+            timestampsFiles=",".join(TSfiles),
+            IFOs=",".join(IFOs),
+            assumeSqrtSX=1,
         )
+        print(
+            "predict_fstat() returned: E[2F]={}+-{}".format(twoF_expected, twoF_sigma)
+        )
+        self.assertTrue(twoF_expected == 4)
+        self.assertAlmostEqual(twoF_sigma, chi2.std(df=4), places=5)
+
+    def test_PFS_signal(self):
+        twoF_expected, twoF_sigma = pyfstat.helper_functions.predict_fstat(
+            h0=1,
+            cosi=0,
+            psi=0,
+            Alpha=0,
+            Delta=0,
+            minStartTime=default_Writer_params["tstart"],
+            duration=default_Writer_params["duration"],
+            IFOs=default_Writer_params["detectors"],
+            assumeSqrtSX=1,
+        )
+        print(
+            "predict_fstat() returned: E[2F]={}+-{}".format(twoF_expected, twoF_sigma)
+        )
+        self.assertTrue(twoF_expected > 4)
+        self.assertTrue(twoF_sigma > 0)
+
+
+class TestBaseSearchClass(unittest.TestCase):
+    # TODO test the basic methods
+    pass
 
 
 class TestComputeFstat(BaseForTestsWithData):
@@ -612,7 +669,7 @@ class TestComputeFstat(BaseForTestsWithData):
         )
         self.assertTrue(np.abs(predicted_FS - FS_from_file) / FS_from_file < 0.3)
 
-        injectSourcesdict = pyfstat.core.read_par(injectSources)
+        injectSourcesdict = search.read_par(filename=injectSources)
         injectSourcesdict["F0"] = injectSourcesdict["Freq"]
         injectSourcesdict["F1"] = injectSourcesdict["f1dot"]
         injectSourcesdict["F2"] = injectSourcesdict["f2dot"]
@@ -750,6 +807,54 @@ class TestComputeFstatNoNoise(BaseForTestsWithData):
         self.assertTrue(np.abs(predicted_FS - FS) / FS < 0.3)
 
 
+class TestSearchForSignalWithJumps(TestBaseSearchClass):
+    def test_shift_matrix(self):
+        search = pyfstat.SearchForSignalWithJumps()
+        dT = 10
+        a = search._shift_matrix(4, dT)
+        b = np.array(
+            [
+                [
+                    1,
+                    2 * np.pi * dT,
+                    2 * np.pi * dT ** 2 / 2.0,
+                    2 * np.pi * dT ** 3 / 6.0,
+                ],
+                [0, 1, dT, dT ** 2 / 2.0],
+                [0, 0, 1, dT],
+                [0, 0, 0, 1],
+            ]
+        )
+        self.assertTrue(np.array_equal(a, b))
+
+    def test_shift_coefficients(self):
+        search = pyfstat.SearchForSignalWithJumps()
+        thetaA = np.array([10.0, 1e2, 10.0, 1e2])
+        dT = 100
+
+        # Calculate the 'long' way
+        thetaB = np.zeros(len(thetaA))
+        thetaB[3] = thetaA[3]
+        thetaB[2] = thetaA[2] + thetaA[3] * dT
+        thetaB[1] = thetaA[1] + thetaA[2] * dT + 0.5 * thetaA[3] * dT ** 2
+        thetaB[0] = thetaA[0] + 2 * np.pi * (
+            thetaA[1] * dT + 0.5 * thetaA[2] * dT ** 2 + thetaA[3] * dT ** 3 / 6.0
+        )
+
+        self.assertTrue(np.array_equal(thetaB, search._shift_coefficients(thetaA, dT)))
+
+    def test_shift_coefficients_loop(self):
+        search = pyfstat.SearchForSignalWithJumps()
+        thetaA = np.array([10.0, 1e2, 10.0, 1e2])
+        dT = 1e1
+        thetaB = search._shift_coefficients(thetaA, dT)
+        self.assertTrue(
+            np.allclose(
+                thetaA, search._shift_coefficients(thetaB, -dT), rtol=1e-9, atol=1e-9
+            )
+        )
+
+
 class TestSemiCoherentSearch(BaseForTestsWithData):
     label = "TestSemiCoherentSearch"
     detectors = "H1,L1"
@@ -1136,8 +1241,16 @@ class TestMCMCSemiCoherentSearch(BaseForMCMCSearchTests):
     def test_semi_coherent_MCMC(self):
 
         theta = {
-            "F0": {"type": "unif", "lower": self.F0 - 1e-6, "upper": self.F0 + 1e-6,},
-            "F1": {"type": "unif", "lower": self.F1 - 1e-10, "upper": self.F1 + 1e-10,},
+            "F0": {
+                "type": "unif",
+                "lower": self.F0 - 1e-6,
+                "upper": self.F0 + 1e-6,
+            },
+            "F1": {
+                "type": "unif",
+                "lower": self.F1 - 1e-10,
+                "upper": self.F1 + 1e-10,
+            },
             "F2": self.F2,
             "Alpha": self.Alpha,
             "Delta": self.Delta,
@@ -1188,8 +1301,16 @@ class TestMCMCFollowUpSearch(BaseForMCMCSearchTests):
     def test_MCMC_followup_search(self):
 
         theta = {
-            "F0": {"type": "unif", "lower": self.F0 - 1e-6, "upper": self.F0 + 1e-6,},
-            "F1": {"type": "unif", "lower": self.F1 - 1e-10, "upper": self.F1 + 1e-10,},
+            "F0": {
+                "type": "unif",
+                "lower": self.F0 - 1e-6,
+                "upper": self.F0 + 1e-6,
+            },
+            "F1": {
+                "type": "unif",
+                "lower": self.F1 - 1e-10,
+                "upper": self.F1 + 1e-10,
+            },
             "F2": self.F2,
             "Alpha": self.Alpha,
             "Delta": self.Delta,
@@ -1208,7 +1329,9 @@ class TestMCMCFollowUpSearch(BaseForMCMCSearchTests):
             log10beta_min=-1,
         )
         self.search.run(
-            plot_walkers=False, NstarMax=NstarMax, Nsegs0=nsegs,
+            plot_walkers=False,
+            NstarMax=NstarMax,
+            Nsegs0=nsegs,
         )
         self.search.print_summary()
         self._check_twoF_predicted()
@@ -1261,7 +1384,6 @@ class TestMCMCTransientSearch(BaseForMCMCSearchTests):
                 "upper": self.Writer.duration - 2 * self.Writer.Tsft,
             },
         }
-        nsegs = 10
         self.search = pyfstat.MCMCTransientSearch(
             label=self.label,
             outdir=self.outdir,
